@@ -4,32 +4,33 @@ from playhouse.shortcuts import model_to_dict
 
 from qa_data_manager.data_base_model import DoctorPatient
 
+"""
+Связь доктора с пациентом.
+    Поля:
+        * doctor_id - Идентификатор доктора; Обязательное поле, устанавливается при инициализации класса из параметра doctor.
+        * patient_id - Идентификатор пациента; Обязательное поле, устанавливается при инициализации класса из параметра patient.
+    
+    Метод generate():
+        - Сохраняет объект BindDoctorPatient в базу данных.
+        - Возвращает модель таблицы DoctorPatient с данными сгенерированной связи.
+"""
+
 
 class BindDoctorPatient:
 
-    def __init__(self):
-        self._doctor_id = ''
-        self._patient_id = ''
-        self._created_at = datetime.datetime.now()
-        self._updated_at = datetime.datetime.now()
-
-    def with_doctor(self, doctor):
+    def __init__(self, doctor, patient):
         self._doctor_id = doctor.get('id')
-        return self
-
-    def with_patient(self, patient):
         self._patient_id = patient.get('id')
-        return self
 
     def generate(self):
         doctor_patient = DoctorPatient(confirm_appointment=0,
-                                       created_at=self._created_at,
+                                       created_at=datetime.datetime.now(),
                                        doctor=self._doctor_id,
                                        doctor_new=1,
                                        message='hello user',
                                        patient=self._patient_id,
                                        patient_new=1,
                                        source='admin',
-                                       updated_at=self._updated_at)
+                                       updated_at=datetime.datetime.now())
         doctor_patient.save()
         return model_to_dict(doctor_patient)
