@@ -1,12 +1,19 @@
 from faker import Faker
+from playhouse.shortcuts import model_to_dict
 
 from qa_data_manager.data_base_model import Clinics
 
+"""
+Генерация клиники.
+    Метод generate():
+        - Сохраняет объект GenerateClinic в базу данных
+        - Возвращает модель таблицы Clinics с данными сгенерированной клиники.
+"""
 
 class GenerateClinic:
     __fake = Faker('ru_RU')
 
-    def create(self):
+    def generate(self):
         clinic = Clinics(avatar=self.__fake.image_url(),
                          city=self.__fake.city(),
                          created_at=self.__fake.date(pattern="%Y-%m-%d %H:%M:%S", end_datetime=None),
@@ -22,4 +29,4 @@ class GenerateClinic:
                          type='default',
                          updated_at=self.__fake.date(pattern="%Y-%m-%d %H:%M:%S", end_datetime=None))
         clinic.save()
-        return clinic
+        return model_to_dict(clinic)
